package App::RegexpCommonUtils;

our $DATE = '2016-12-31'; # DATE
our $VERSION = '0.002'; # VERSION

use 5.010001;
use strict;
use warnings;

1;
# ABSTRACT: CLI utilities related to Regexp::Common

__END__

=pod

=encoding UTF-8

=head1 NAME

App::RegexpCommonUtils - CLI utilities related to Regexp::Common

=head1 VERSION

This document describes version 0.002 of App::RegexpCommonUtils (from Perl distribution App-RegexpCommonUtils), released on 2016-12-31.

=head1 SYNOPSIS

=head1 DESCRIPTION

This distribution includes several utilities related to L<Regexp::Common>:

=over

=item * L<get-regexp-common-pattern>

=item * L<list-regexp-common-modules>

=item * L<list-regexp-common-patterns>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-RegexpCommonUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-RegexpCommonUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-RegexpCommonUtils>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
